import React from 'react';
import { JupyterFrontEnd } from '@jupyterlab/application';
import { ReactWidget } from '@jupyterlab/apputils';
import { IDocumentManager } from '@jupyterlab/docmanager';
import StyledInstance from './components/instance/Instance';
import StyledWorkflow from './components/workflow/Workflow';
import StyledWorkflowsPanel from './components/WorkflowsPanel';
import StyledInstancesPanel from './components/InstancesPanel';
import StyledIndexPanel from './components/IndexPanel';
import StyledHeader from './components/Header';
import StyledFooter from './components/Footer';
import styled from 'styled-components';

import { MemoryRouter as Router, Routes, Route } from 'react-router-dom';

const LauncherContainer = styled.div``;

export class Launcher extends ReactWidget {
  constructor(app: JupyterFrontEnd, docTrack: IDocumentManager) {
    super();
    this.app = app;
    this.docTrack = docTrack;
    this.addClass('jp-ReactWidget');
    this.addClass('epi2melabs-wfpage-widget');
  }

  render(): JSX.Element {
    return (
      <Router>
        <LauncherContainer>
          <main style={{ position: 'relative' }}>
            <StyledHeader />
            <div>
              <Routes>
                <Route path="/workflows/:name">
                  <Route path=":instance_id" element={<StyledWorkflow />} />
                  <Route path="" element={<StyledWorkflow />} />
                </Route>
                <Route path="/workflows" element={<StyledWorkflowsPanel />} />
                <Route
                  path="/instances/:id"
                  element={
                    <StyledInstance docTrack={this.docTrack} app={this.app} />
                  }
                />
                <Route path="/instances" element={<StyledInstancesPanel />} />
                <Route path="/" element={<StyledIndexPanel />} />
              </Routes>
            </div>
            <StyledFooter />
          </main>
        </LauncherContainer>
      </Router>
    );
  }

  public app: JupyterFrontEnd;
  public docTrack: IDocumentManager;
}
